import { createRequestHandler as createRemixRequestHandler } from '@netlify/remix-runtime';
export function createRequestHandler({ build, mode, getLoadContext, }) {
    const remixHandler = createRemixRequestHandler(build, mode);
    const assetPath = build.assets.url.split('/').slice(0, -1).join('/');
    return async (request, context) => {
        const { pathname } = new URL(request.url);
        // Skip the handler for static files
        if (pathname.startsWith(`${assetPath}/`)) {
            return;
        }
        try {
            const loadContext = (await getLoadContext?.(request, context)) || context;
            const response = await remixHandler(request, loadContext);
            // A useful header for debugging
            response.headers.set('x-nf-runtime', 'Edge');
            if (response.status === 404) {
                // Check if there is a matching static file
                const originResponse = await context.next({
                    sendConditionalRequest: true,
                });
                if (originResponse.status !== 404) {
                    return originResponse;
                }
            }
            return response;
        }
        catch (error) {
            console.error(error);
            return new Response('Internal Error', { status: 500 });
        }
    };
}
